diff -pruN 2.3.2-1/debian/changelog 2.3.2-2/debian/changelog
--- 2.3.2-1/debian/changelog	2024-01-25 03:43:56.000000000 +0000
+++ 2.3.2-2/debian/changelog	2024-05-02 19:42:17.000000000 +0000
@@ -1,9 +1,18 @@
+acl (2.3.2-2) unstable; urgency=medium
+
+  * Add patch from upstream:
+    - Fix memory wasting loop in __acl_get_uid() if user does not exist.
+
+ -- Guillem Jover <guillem@debian.org>  Thu, 02 May 2024 21:42:17 +0200
+
 acl (2.3.2-1) unstable; urgency=medium
 
   * New upstream release.
     - Remove upstream patches included in this release.
     - Update upstream signing key.
     - Do not list no longer existing files in not-installed.
+    - Declare s_str directly in string_obj_tag allow proper bounds checking,
+      triggered with -D_FORTIFY_SOURCE=3. Closes: #1060022
   * Update libacl-dev.docs to use the destdir so that we can remove these
     entries from not-installed.
   * Quote strings with variables in maintscripts.
diff -pruN 2.3.2-1/debian/patches/0001-libmisc-__acl_get_uid-fix-memory-wasting-loop-if-use.patch 2.3.2-2/debian/patches/0001-libmisc-__acl_get_uid-fix-memory-wasting-loop-if-use.patch
--- 2.3.2-1/debian/patches/0001-libmisc-__acl_get_uid-fix-memory-wasting-loop-if-use.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.3.2-2/debian/patches/0001-libmisc-__acl_get_uid-fix-memory-wasting-loop-if-use.patch	2024-05-02 19:25:22.000000000 +0000
@@ -0,0 +1,48 @@
+From 56abe432b65801f31277fb9a3bca0f9e31502315 Mon Sep 17 00:00:00 2001
+From: Matthias Gerstner <matthias.gerstner@suse.de>
+Date: Thu, 25 Apr 2024 12:43:49 +0200
+Subject: [PATCH acl] libmisc: __acl_get_uid(): fix memory wasting loop if user
+ does not exist
+
+I noticed that `acl_from_text()` unexpectedly returns ENOMEM for invalid
+user names. The reason for this is a missing break statement in the for
+loop in `__acl_get_uid()`, which causes the loop to act as if ERANGE was
+returned from `getpwnam_r()`, thereby exponentially increasing the
+buffer size to (in my case) multiple gigabytes, until `grow_buffer()`
+reports ENOMEM, which terminates the `__acl_get_uid()` function.
+
+This is a pretty costly "no such user" lookup that can disturb a
+process's heap memory management, but can also cause a process to fail
+e.g. if it is multithreaded and other threads encounter an ENOMEM,
+before `__acl_get_uid()` frees the gigantic heap buffer and returns.
+The allocated memory isn't actually used. Therefore on Linux it should
+not affect other processes by default, due to its overcommit memory
+and lazy memory allocation strategy.
+
+Fix this by properly terminating the for loop on any conditions except
+an ERANGE error being reported. The same break statement correctly
+exists in `__acl_get_gid()` already.
+
+Origin: upstream, commit56abe432b65801f31277fb9a3bca0f9e31502315
+Forwarded: not-needed
+Fixes: 3737f00 ("use thread-safe getpwnam_r and getgrnam_r")
+Signed-off-by: Andreas Gruenbacher <agruenba@redhat.com>
+---
+ libmisc/uid_gid_lookup.c | 1 +
+ 1 file changed, 1 insertion(+)
+
+diff --git a/libmisc/uid_gid_lookup.c b/libmisc/uid_gid_lookup.c
+index a4f21f6..74baab4 100644
+--- a/libmisc/uid_gid_lookup.c
++++ b/libmisc/uid_gid_lookup.c
+@@ -91,6 +91,7 @@ __acl_get_uid(const char *token, uid_t *uid_p)
+ 		if (err == ERANGE)
+ 			continue;
+ 		errno = err ? err : EINVAL;
++		break;
+ 	}
+ 	free(buffer);
+ 	return result ? 0 : -1;
+-- 
+2.43.0
+
diff -pruN 2.3.2-1/debian/patches/series 2.3.2-2/debian/patches/series
--- 2.3.2-1/debian/patches/series	2024-01-25 03:36:59.000000000 +0000
+++ 2.3.2-2/debian/patches/series	2024-05-02 19:38:33.000000000 +0000
@@ -1,4 +1,4 @@
 # Upstream patches
-# <none>
+0001-libmisc-__acl_get_uid-fix-memory-wasting-loop-if-use.patch
 # Local patches
 getfacl-fix-uninitialized-variable.patch
